@@ -384,6 +384,25 @@ bool ZrtpQueue::srtpSecretsReady(SrtpSecret_t* secrets, EnableSecurity part)
     CryptoContext* pcc;
     CryptoContext* recvCryptoContext;
     CryptoContext* senderCryptoContext;
+    int cipher;
+    int authn;
+    int authKeyLen;
+
+    if (secrets->authAlgorithm == Sha1) {
+        authn = SrtpAuthenticationSha1Hmac;
+        authKeyLen = 20;
+    }
+    
+    if (secrets->authAlgorithm == Skein) {
+        authn = SrtpAuthenticationSkeinHmac;
+        authKeyLen = 32;
+    }
+
+    if (secrets->symEncAlgorithm == Aes)
+        cipher = SrtpEncryptionAESCM;
+    
+    if (secrets->symEncAlgorithm == TwoFish)
+        cipher = SrtpEncryptionTWOCM;
 
     if (part == ForSender) {
         // To encrypt packets: intiator uses initiator keys,
@@ -395,14 +414,14 @@ bool ZrtpQueue::srtpSecretsReady(SrtpSecret_t* secrets, EnableSecurity part)
                     0,
                     0,
                     0L,                                      // keyderivation << 48,
-                    SrtpEncryptionAESCM,                     // encryption algo
-                    SrtpAuthenticationSha1Hmac,              // authtentication algo
+                    cipher,                                  // encryption algo
+                    authn,                                   // authtentication algo
                     (unsigned char*)secrets->keyInitiator,   // Master Key
                     secrets->initKeyLen / 8,                 // Master Key length
                     (unsigned char*)secrets->saltInitiator,  // Master Salt
                     secrets->initSaltLen / 8,                // Master Salt length
                     secrets->initKeyLen / 8,                 // encryption keyl
-                    20,                                      // authentication key len
+                    authKeyLen,                              // authentication key len
                     secrets->initSaltLen / 8,                // session salt len
                     secrets->srtpAuthTagLen / 8);            // authentication tag lenA
         }
@@ -411,14 +430,14 @@ bool ZrtpQueue::srtpSecretsReady(SrtpSecret_t* secrets, EnableSecurity part)
                     0,
                     0,
                     0L,                                      // keyderivation << 48,
-                    SrtpEncryptionAESCM,                     // encryption algo
-                    SrtpAuthenticationSha1Hmac,              // authtentication algo
+                    cipher,                                  // encryption algo
+                    authn,                                   // authtentication algo
                     (unsigned char*)secrets->keyResponder,   // Master Key
                     secrets->respKeyLen / 8,                 // Master Key length
                     (unsigned char*)secrets->saltResponder,  // Master Salt
                     secrets->respSaltLen / 8,                // Master Salt length
                     secrets->respKeyLen / 8,                 // encryption keyl
-                    20,                                      // authentication key len
+                    authKeyLen,                              // authentication key len
                     secrets->respSaltLen / 8,                // session salt len
                     secrets->srtpAuthTagLen / 8);            // authentication tag len
         }
@@ -446,14 +465,14 @@ bool ZrtpQueue::srtpSecretsReady(SrtpSecret_t* secrets, EnableSecurity part)
                     0,
                     0,
                     0L,                                      // keyderivation << 48,
-                    SrtpEncryptionAESCM,                     // encryption algo
-                    SrtpAuthenticationSha1Hmac,              // authtication algo
+                    cipher,                                  // encryption algo
+                    authn,                                   // authtentication algo
                     (unsigned char*)secrets->keyResponder,   // Master Key
                     secrets->respKeyLen / 8,                 // Master Key length
                     (unsigned char*)secrets->saltResponder,  // Master Salt
                     secrets->respSaltLen / 8,                // Master Salt length
                     secrets->respKeyLen / 8,                 // encryption keyl
-                    20,                                      // authentication key len
+                    authKeyLen,                              // authentication key len
                     secrets->respSaltLen / 8,                // session salt len
                     secrets->srtpAuthTagLen / 8);            // authentication tag len
         }
@@ -462,14 +481,14 @@ bool ZrtpQueue::srtpSecretsReady(SrtpSecret_t* secrets, EnableSecurity part)
                     0,
                     0,
                     0L,                                      // keyderivation << 48,
-                    SrtpEncryptionAESCM,                     // encryption algo
-                    SrtpAuthenticationSha1Hmac,              // authtication algo
+                    cipher,                                  // encryption algo
+                    authn,                                   // authtentication algo
                     (unsigned char*)secrets->keyInitiator,   // Master Key
                     secrets->initKeyLen / 8,                 // Master Key length
                     (unsigned char*)secrets->saltInitiator,  // Master Salt
                     secrets->initSaltLen / 8,                // Master Salt length
                     secrets->initKeyLen / 8,                 // encryption keyl
-                    20,                                      // authentication key len
+                    authKeyLen,                              // authentication key len
                     secrets->initSaltLen / 8,                // session salt len
                     secrets->srtpAuthTagLen / 8);            // authentication tag len
         }
