@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2006-2007 Werner Dittmann
+  Copyright (C) 2006-2010 Werner Dittmann
 
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,14 @@
 #ifndef _ZRTPPACKETCONFIRM_H_
 #define _ZRTPPACKETCONFIRM_H_
 
+/**
+ * @file ZrtpPacketConfirm.h
+ * @brief The ZRTP Confirm message
+ *  
+ * @ingroup GNU_ZRTP
+ * @{
+ */
+
 #include <libzrtpcpp/ZrtpPacketBase.h>
 
 /**
@@ -25,8 +33,8 @@
  *
  * The ZRTP message Confirm. The implementation sends this
  * to confirm the switch to SRTP (encrypted) mode. The contents of
- * the Confirm message are encrypted, thus the implementation can
- * check if SRTP work correctly.
+ * the Confirm message are encrypted, thus the implementation
+ * can check if the secret keys work.
  *
  * @author Werner Dittmann <Werner.Dittmann@t-online.de>
  */
@@ -34,27 +42,58 @@
 class ZrtpPacketConfirm : public ZrtpPacketBase {
 
     private:
-        Confirm_t* confirmHeader;
+        Confirm_t* confirmHeader;   ///< Point to the Confirm message part
 
     public:
-        ZrtpPacketConfirm();                    /* Creates a Confirm packet */
-        ZrtpPacketConfirm(uint32_t sl);		/* Creates a Confirm packet with default data */
-        ZrtpPacketConfirm(uint8_t* d);          /* Creates a Confirm packet from received data */
+        /// Creates a Confirm packet with default data
+        ZrtpPacketConfirm();
+        
+        /// Creates a Confirm packet with default data and a given signature length
+        ZrtpPacketConfirm(uint32_t sl);
+
+        /// Creates a Confirm packet from received data
+        ZrtpPacketConfirm(uint8_t* d);
+
+        /// Normal destructor
         virtual ~ZrtpPacketConfirm();
 
+        /// Check is SAS verify flag is set
         const bool isSASFlag()            { return confirmHeader->flags & 0x4; }
+
+        /// Get pointer to filler bytes (contains one bit of signature length)
         const uint8_t* getFiller()        { return confirmHeader->filler; }
+
+        /// Get pointer to IV data, fixed byte array
         const uint8_t* getIv()            { return confirmHeader->iv; }
+
+        /// Get pointer to MAC data, fixed byte array
         const uint8_t* getHmac()          { return confirmHeader->hmac; }
+
+        /// Get Expiration time data
         const uint32_t getExpTime()       { return ntohl(confirmHeader->expTime); }
+
+        /// Get pointer to initial hash chain (H0) data, fixed byte array
         uint8_t* getHashH0()              { return confirmHeader->hashH0; }
+
+        /// get the signature length in words
         uint32_t getSignatureLength();
 
+        /// set SAS verified flag
         void setSASFlag()            { confirmHeader->flags |= 0x4; }
+        
+        /// Set MAC data, fixed length byte array
         void setHmac(uint8_t* text)  { memcpy(confirmHeader->hmac, text, sizeof(confirmHeader->hmac)); }
+
+        /// Set IV data, fixed length byte array
         void setIv(uint8_t* text)    { memcpy(confirmHeader->iv, text, sizeof(confirmHeader->iv)); }
+        
+        /// Set expiration time data
         void setExpTime(uint32_t t)  { confirmHeader->expTime = htonl(t); }
+
+        /// Set initial hash chain (H0) data, fixed length byte array
         void setHashH0(uint8_t* t)   { memcpy(confirmHeader->hashH0, t, sizeof(confirmHeader->hashH0)); }
+
+        /// Set signature length in words
         void setSignatureLength(uint32_t sl);
 
     private:
@@ -67,5 +106,8 @@ class ZrtpPacketConfirm : public ZrtpPacketBase {
 
 };
 
+/**
+ * @}
+ */
 #endif // ZRTPPACKETCONFIRM
 
